package com.bwie.auth.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.bwie.auth.feign.SystemRemote;
import com.bwie.auth.feign.falltry.SystemRemoteService;
import com.bwie.auth.service.AuthService;
import com.bwie.common.constants.JwtConstants;
import com.bwie.common.constants.TokenConstants;
import com.bwie.common.domain.User;
import com.bwie.common.domain.response.JwtResponse;
import com.bwie.common.result.Result;
import com.bwie.common.utils.JwtUtils;
import com.bwie.common.utils.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Service;

import java.util.LinkedHashMap;
import java.util.Objects;
import java.util.UUID;
import java.util.concurrent.TimeUnit;
import java.util.function.ToDoubleBiFunction;

/**
 * @Author：zhangchengzhi
 * @Package：com.bwie.auth.service.impl
 * @Project：week_7.30_house
 * @name：AuthServiceImpl
 * @Date：2024/7/30 9:37
 */
@Service
public class AuthServiceImpl implements AuthService {


   @Autowired
   private StringRedisTemplate redisTemplate;

   @Autowired
   private SystemRemote systemRemote;

    @Override
    public Result login(User user) {

        if (StringUtils.isAnyBlank(user.getUserPhone(),user.getUserPwd())){
            return Result.error("手机号或密码不能为空");
        }


        Result<User> result = systemRemote.login(user.getUserPhone());

        User userlogin = result.getData();

        if (null==userlogin){
            return Result.error("手机号错误");
        }

        if (!user.getUserPwd().equals(userlogin.getUserPwd())){
            return Result.error("密码错误");
        }

        String userKey = UUID.randomUUID().toString().replace("-", "");

        LinkedHashMap<String, Object> map = new LinkedHashMap<>();

        map.put(JwtConstants.USER_KEY,userKey);

        String token = JwtUtils.createToken(map);

        redisTemplate.opsForValue().set(TokenConstants.LOGIN_TOKEN_KEY+userKey, JSONObject.toJSONString(userlogin),30, TimeUnit.MINUTES);

        JwtResponse jwtResponse = new JwtResponse();

        jwtResponse.setToken(token);

        jwtResponse.setExpireTimeStr("30Min");

        return Result.success(jwtResponse);
    }
}
