package com.bwie.gateway.filters;

import com.bwie.common.constants.TokenConstants;
import com.bwie.common.utils.JwtUtils;
import com.bwie.common.utils.StringUtils;
import com.bwie.gateway.config.IgnoreWhiteConfig;
import com.bwie.gateway.utils.GatewayUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.gateway.filter.GatewayFilterChain;
import org.springframework.cloud.gateway.filter.GlobalFilter;
import org.springframework.core.Ordered;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.http.server.reactive.ServerHttpRequest;
import org.springframework.stereotype.Component;
import org.springframework.web.server.ServerWebExchange;
import reactor.core.publisher.Mono;

import java.util.List;
import java.util.concurrent.TimeUnit;

/**
 * @Author：zhangchengzhi
 * @Package：com.bwie.gateway.filters
 * @Project：week_7.30_house
 * @name：GlobalFilter
 * @Date：2024/7/30 9:43
 */
@Component
public class GateWayFilter implements GlobalFilter,Ordered {

    @Autowired
    private StringRedisTemplate redisTemplate;

    @Autowired
    private IgnoreWhiteConfig ignoreWhiteConfig;

    @Override
    public Mono<Void> filter(ServerWebExchange exchange, GatewayFilterChain chain) {

        ServerHttpRequest request = exchange.getRequest();

        String path = request.getURI().getPath();

        List<String> whites = ignoreWhiteConfig.getWhites();

        if (StringUtils.matches(path,whites)){
            return chain.filter(exchange);
        }

        String token = request.getHeaders().getFirst(TokenConstants.TOKEN);

        try {
            JwtUtils.parseToken(token);
        } catch (Exception e) {
          return GatewayUtils.errorResponse(exchange,"token不合法");
        }

        String userKey = JwtUtils.getUserKey(token);

        if (!redisTemplate.hasKey(TokenConstants.LOGIN_TOKEN_KEY+userKey)){
            return GatewayUtils.errorResponse(exchange,"token已过期");
        }else {
            redisTemplate.expire(TokenConstants.LOGIN_TOKEN_KEY+userKey,30, TimeUnit.MINUTES);
        }
        return chain.filter(exchange);
    }

    @Override
    public int getOrder() {
        return 0;
    }
}
